@@ -4,15 +4,17 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.03';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000027-000001"; }
+sub IDENTIFICATION { return "000001-000027-000003"; }
 
 sub preference { return 0; }
 
+sub known_actions { return [ qw/SQL_OUTPUT/ ]; }
+
 sub init {
 	my $obj = shift;
 	$obj->{-mempool}->register('output_format','plain');
@@ -27,7 +29,7 @@ sub handle_action {
 			my $output = join ',',@{$action{fieldnames}};
 			$output .= "\n";
 			for (@{$action{result}}) {
-				$output .= join ',',map { /^\d+$/ ? $_ : '"'.$_.'"' } @$_;
+				$output .= join ',',map { defined($_)?(/^\d+$/ ? $_ : '"'.$_.'"'):"NULL" } @$_;
 				$output .= "\n";
 			}
 			$action{action} = 'OUTPUT';
